import { Component, Inject, forwardRef } from '@angular/core';
import { DataTable } from './table.component';
import { PAGINATION_TEMPLATE } from './pagination.template';
import { PAGINATION_STYLE } from "./pagination.style";
import * as $ from 'jquery';
var DataTablePagination = (function () {
    function DataTablePagination(dataTable) {
        this.dataTable = dataTable;
    }
    DataTablePagination.prototype.ngAfterViewInit = function () {
        if (this.dataTable.limit < this.dataTable.itemCount) {
            $(".fs-pagination-next").removeClass("fs-pagination-button-disable");
        }
    };
    DataTablePagination.prototype.pageBack = function () {
        if (this.currentFirstColumn == 1)
            return;
        this.dataTable.offset -= Math.min(this.dataTable.limit, this.dataTable.offset);
        if (this.currentFirstColumn == this.page) {
            $(".fs-pagination-prev").addClass("fs-pagination-button-disable");
        }
        $(".fs-pagination-next").removeClass("fs-pagination-button-disable");
        this.dataTable.goBack.emit(this.page);
    };
    DataTablePagination.prototype.choosePage = function (event) {
        if ($(".pagition-pagesize-list").hasClass("fn-hide")) {
            $(".pagition-pagesize-list").removeClass("fn-hide");
        }
        else {
            $(".pagition-pagesize-list").addClass("fn-hide");
        }
        document.body.addEventListener("onclick", this.bodyClick);
    };
    DataTablePagination.prototype.bodyClick = function () {
        document.body.removeEventListener("onclick", this.bodyClick);
        $(".pagition-pagesize-list").addClass("fn-hide");
    };
    DataTablePagination.prototype.chooseItem = function (event) {
        this.dataTable.limit = Number(event.target.textContent);
        $(".pagition-select-title")[0].innerText = event.target.textContent;
        this.dataTable.updateDatas();
        $(".pagition-pagesize-list").addClass("fn-hide");
    };
    DataTablePagination.prototype.pageForward = function () {
        var off = this.dataTable.itemCount - this.currentFirstColumn;
        if (off < this.dataTable.limit)
            return;
        this.dataTable.offset += this.dataTable.limit;
        if (this.currentLastColumn >= this.dataTable.itemCount) {
            $(".fs-pagination-next").addClass("fs-pagination-button-disable");
        }
        $(".fs-pagination-prev").removeClass("fs-pagination-button-disable");
        this.dataTable.goForward.emit(this.page);
    };
    DataTablePagination.prototype.pageFirst = function () {
        this.dataTable.offset = 0;
    };
    DataTablePagination.prototype.pageLast = function () {
        this.dataTable.offset = (this.maxPage - 1) * this.dataTable.limit;
    };
    Object.defineProperty(DataTablePagination.prototype, "currentFirstColumn", {
        get: function () {
            return (this.page - 1) * this.limit + 1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DataTablePagination.prototype, "currentLastColumn", {
        get: function () {
            if (this.page * this.limit > this.dataTable.itemCount) {
                return this.dataTable.itemCount;
            }
            else {
                return this.page * this.limit;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DataTablePagination.prototype, "maxPage", {
        get: function () {
            return Math.ceil(this.dataTable.itemCount / this.dataTable.limit);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DataTablePagination.prototype, "limit", {
        get: function () {
            return this.dataTable.limit;
        },
        set: function (value) {
            this.dataTable.limit = Number(value); // TODO better way to handle that value of number <input> is string?
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DataTablePagination.prototype, "page", {
        get: function () {
            return this.dataTable.page;
        },
        set: function (value) {
            this.dataTable.page = Number(value);
        },
        enumerable: true,
        configurable: true
    });
    return DataTablePagination;
}());
export { DataTablePagination };
DataTablePagination.decorators = [
    { type: Component, args: [{
                selector: 'data-table-pagination',
                template: PAGINATION_TEMPLATE,
                styles: [PAGINATION_STYLE]
            },] },
];
/** @nocollapse */
DataTablePagination.ctorParameters = function () { return [
    { type: DataTable, decorators: [{ type: Inject, args: [forwardRef(function () { return DataTable; }),] },] },
]; };
//# sourceMappingURL=pagination.component.js.map